CompositeNodeInfo

Struct CompositeNodeInfo 

pub struct CompositeNodeInfo {
    pub parent_topological_paths: Option<Vec<Option<String>>>,
    pub topological_path: Option<String>,
    pub composite: Option<CompositeInfo>,
    pub parent_monikers: Option<Vec<Option<String>>>,
    pub moniker: Option<String>,
    /* private fields */
}
Contains information for a composite node.

Fields

parent_topological_paths: Option<Vec<Option<String>>>

The topological paths of the parent nodes of this composite, ordered by index.

topological_path: Option<String>

The topological path of the created composite node. Empty if not created.

composite: Option<CompositeInfo>parent_monikers: Option<Vec<Option<String>>>

The monikers of the parent nodes of this composite, ordered by index.

moniker: Option<String>

The moniker of the created composite node. Empty if not created.