pub struct ManagerRestartWithDictionaryAndPowerDependenciesRequest {
pub moniker: String,
pub dictionary: DictionaryRef,
pub power_dependencies: Vec<LevelDependency>,
pub cpu_token_override: Option<Event>,
}Fields
moniker: StringMoniker of the node to restart with the dictionary and power dependencies.
dictionary: DictionaryRefDictionary to give to the drivers on and under the nodes.
power_dependencies: Vec<LevelDependency>Custom power dependencies to give to the restarted node.
cpu_token_override: Option<Event>Custom cpu token to give to the restarted node.